@@ -18,6 +18,20 @@ from glean_parser import translate
 ROOT = Path(__file__).parent
 
 
+def run_linters(files):
+    # Syntax check on the generated files.
+    # Only run this test if swiftc is on the path.
+    if shutil.which("swiftc"):
+        for filepath in files:
+            subprocess.check_call(["swiftc", "-parse", filepath])
+
+    # Lint check on the generated files.
+    # Only run this test if swiftlint is on the path.
+    if shutil.which("swiftlint"):
+        for filepath in files:
+            subprocess.check_call(["swiftlint", "lint", filepath])
+
+
 def test_parser(tmpdir):
     """Test translating metrics to Swift files."""
     tmpdir = Path(str(tmpdir))
@@ -36,17 +50,36 @@ def test_parser(tmpdir):
         assert "جمع 搜集" in content
         assert 'category: ""' in content
 
-    # Syntax check on the generated files.
-    # Only run this test if swiftc is on the path.
-    if shutil.which("swiftc"):
-        for filepath in tmpdir.glob("*.swift"):
-            subprocess.check_call(["swiftc", "-parse", filepath])
+    run_linters(tmpdir.glob("*.swift"))
 
-    # Lint check on the generated files.
-    # Only run this test if swiftlint is on the path.
-    if shutil.which("swiftlint"):
-        for filepath in tmpdir.glob("*.swift"):
-            subprocess.check_call(["swiftlint", "lint", filepath])
+
+def test_ping_parser(tmpdir):
+    """Test translating pings to Swift files."""
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "pings.yaml",
+        "swift",
+        tmpdir,
+        {"namespace": "Foo"},
+        {"allow_reserved": True},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(["Metrics.swift"])
+
+    # Make sure descriptions made it in
+    with (tmpdir / "Metrics.swift").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        assert "This is a custom ping" in content
+        # Make sure the namespace option is in effect
+        assert "extension Foo" in content
+        assert "customPing = Ping<NoReasonCodes>" in content
+        assert (
+            "customPingMightBeEmpty = Ping<CustomPingMightBeEmptyReasonCodes>"
+            in content
+        )
+
+    run_linters(tmpdir.glob("*.swift"))
 
 
 def test_swift_generator():
@@ -62,31 +95,30 @@ def test_swift_generator():
 
 
 def test_metric_type_name():
-    # TODO: Events are not yet supported.
-    # event = metrics.Event(
-    #     type="event",
-    #     category="category",
-    #     name="metric",
-    #     bugs=[42],
-    #     notification_emails=["nobody@example.com"],
-    #     description="description...",
-    #     expires="never",
-    #     extra_keys={"my_extra": {"description": "an extra"}},
-    # )
+    event = metrics.Event(
+        type="event",
+        category="category",
+        name="metric",
+        bugs=["42"],
+        notification_emails=["nobody@example.com"],
+        description="description...",
+        expires="never",
+        extra_keys={"my_extra": {"description": "an extra"}},
+    )
 
-    # assert swift.type_name(event) == "EventMetricType<metricKeys>"
+    assert swift.type_name(event) == "EventMetricType<MetricKeys>"
 
-    # event = metrics.Event(
-    #     type="event",
-    #     category="category",
-    #     name="metric",
-    #     bugs=[42],
-    #     notification_emails=["nobody@example.com"],
-    #     description="description...",
-    #     expires="never",
-    # )
+    event = metrics.Event(
+        type="event",
+        category="category",
+        name="metric",
+        bugs=["42"],
+        notification_emails=["nobody@example.com"],
+        description="description...",
+        expires="never",
+    )
 
-    # assert swift.type_name(event) == "EventMetricType<noExtraKeys>"
+    assert swift.type_name(event) == "EventMetricType<NoExtraKeys>"
 
     boolean = metrics.Boolean(
         type="boolean",
@@ -211,3 +243,30 @@ def test_event_extra_keys_in_correct_order(tmpdir):
             "{ case alice = 0 case bob = 1 case charlie = 2" in content
         )
         assert 'allowedExtraKeys: ["alice", "bob", "charlie"]' in content
+
+
+def test_event_extra_keys_with_types(tmpdir):
+    """
+    Assert that the extra keys with types appear with their corresponding types.
+    """
+
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "events_with_types.yaml",
+        "swift",
+        tmpdir,
+        {"namespace": "Foo"},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(["Metrics.swift"])
+
+    with (tmpdir / "Metrics.swift").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        content = " ".join(content.split())
+        assert (
+            "struct PreferenceToggledExtra: EventExtras "
+            "{ val enabled: Bool? val preference: String? "
+            "val swapped: Int32?" in content
+        )
+        assert 'allowedExtraKeys: ["enabled", "preference", "swapped"]' in content
